@@ -74,8 +74,8 @@ apply_f_path_components(torrent::File* file) {
   torrent::Object resultRaw = torrent::Object::create_list();
   torrent::Object::list_type& result = resultRaw.as_list();
 
-  for (torrent::Path::const_iterator itr = file->path()->begin(), last = file->path()->end(); itr != last; itr++)
-    result.push_back(*itr);
+  for (const auto& itr : *file->path())
+    result.push_back(itr);
 
   return resultRaw;
 }
