@@ -5,16 +5,16 @@
 #include <unistd.h>
 #include <rak/address_info.h>
 #include <rak/path.h>
-#include <torrent/connection_manager.h>
-#include <torrent/tracker/tracker.h>
 #include <torrent/torrent.h>
 #include <torrent/rate.h>
+#include <torrent/connection_manager.h>
 #include <torrent/data/file_manager.h>
 #include <torrent/download/resource_manager.h>
+#include <torrent/net/http_stack.h>
+#include <torrent/tracker/tracker.h>
 #include <torrent/utils/log.h>
 #include <torrent/utils/option_strings.h>
 
-#include "core/curl_stack.h"
 #include "core/download.h"
 #include "core/manager.h"
 #include "rpc/scgi.h"
@@ -30,8 +30,8 @@ torrent::Object
 apply_encryption(const torrent::Object::list_type& args) {
   uint32_t options_mask = torrent::ConnectionManager::encryption_none;
 
-  for (torrent::Object::list_const_iterator itr = args.begin(), last = args.end(); itr != last; itr++) {
-    uint32_t opt = torrent::option_find_string(torrent::OPTION_ENCRYPTION, itr->as_string().c_str());
+  for (const auto& arg : args) {
+    uint32_t opt = torrent::option_find_string(torrent::OPTION_ENCRYPTION, arg.as_string().c_str());
 
     if (opt == torrent::ConnectionManager::encryption_none)
       options_mask = torrent::ConnectionManager::encryption_none;
@@ -59,45 +59,20 @@ apply_tos(const torrent::Object::string_type& arg) {
 torrent::Object apply_encoding_list(const std::string& arg) { torrent::encoding_list()->push_back(arg); return torrent::Object(); }
 
 void
-initialize_rpc() {
-  rpc::rpc.initialize();
-
-  rpc::rpc.slot_find_download() = [](const char* hash) {
-      return control->core()->download_list()->find_hex_ptr(hash);
-    };
-  rpc::rpc.slot_find_file() = [](core::Download* d, uint32_t index) -> torrent::File* {
-      if (index >= d->file_list()->size_files())
-        throw torrent::input_error("invalid parameters: index not found");
-
-      return (*d->file_list())[index].get();
-    };
-  rpc::rpc.slot_find_tracker() = [](core::Download* d, uint32_t index) -> torrent::tracker::Tracker {
-      if (index >= d->tracker_controller().size())
-        throw torrent::input_error("invalid parameters: index not found");
-
-      // TODO: This should be rewritten to check if the tracker is valid and use a different
-      // function.
-      return d->tracker_controller().at(index);
-    };
-  rpc::rpc.slot_find_peer() = [](core::Download* d, const torrent::HashString& hash) -> torrent::Peer* {
-      auto itr = d->connection_list()->find(hash.c_str());
-
-      if (itr == d->connection_list()->end())
-        throw torrent::input_error("invalid parameters: hash not found");
-
-      return *itr;
-    };
+initialize_rpc_handlers() {
+  rpc::rpc.initialize_handlers();
 
   unsigned int count = 0;
 
-  for (rpc::CommandMap::const_iterator itr = rpc::commands.begin(), last = rpc::commands.end(); itr != last; itr++, count++) {
-    if (!(itr->second.m_flags & rpc::CommandMap::flag_public_rpc))
+  for (const auto& [name, cmd] : rpc::commands) {
+    if (!(cmd.m_flags & rpc::CommandMap::flag_public_rpc))
       continue;
 
-    rpc::rpc.insert_command(itr->first.c_str(), itr->second.m_parm, itr->second.m_doc);
+    rpc::rpc.insert_command(name.c_str(), cmd.m_parm, cmd.m_doc);
+    ++count;
   }
 
-  lt_log_print(torrent::LOG_RPC_EVENTS, "RPC initialized with %u functions.", count);
+  lt_log_print(torrent::LOG_RPC_EVENTS, "RPC manager initialized with %u functions.", count);
 }
 
 torrent::Object
@@ -105,7 +80,7 @@ apply_scgi(const std::string& arg, int type) {
   if (worker_thread->scgi() != NULL)
     throw torrent::input_error("SCGI already enabled.");
 
-  initialize_rpc();
+  initialize_rpc_handlers();
 
   rpc::SCgi* scgi = new rpc::SCgi;
 
@@ -189,9 +164,9 @@ apply_xmlrpc_dialect(const std::string& arg) {
 
 void
 initialize_command_network() {
-  torrent::ConnectionManager* cm = torrent::connection_manager();
-  torrent::FileManager* fileManager = torrent::file_manager();
-  core::CurlStack* httpStack = control->core()->http_stack();
+  auto cm = torrent::connection_manager();
+  auto fileManager = torrent::file_manager();
+  auto http_stack = torrent::net_thread::http_stack();
 
   CMD2_ANY_STRING  ("encoding.add", std::bind(&apply_encoding_list, std::placeholders::_2));
 
@@ -215,21 +190,21 @@ initialize_command_network() {
   CMD2_VAR_STRING  ("protocol.choke_heuristics.down.leech", "download_leech");
   CMD2_VAR_STRING  ("protocol.choke_heuristics.down.seed",  "download_leech");
 
-  CMD2_ANY         ("network.http.cacert",                std::bind(&core::CurlStack::http_cacert, httpStack));
-  CMD2_ANY_STRING_V("network.http.cacert.set",            std::bind(&core::CurlStack::set_http_cacert, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.capath",                std::bind(&core::CurlStack::http_capath, httpStack));
-  CMD2_ANY_STRING_V("network.http.capath.set",            std::bind(&core::CurlStack::set_http_capath, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.dns_cache_timeout",     std::bind(&core::CurlStack::dns_timeout, httpStack));
-  CMD2_ANY_VALUE_V ("network.http.dns_cache_timeout.set", std::bind(&core::CurlStack::set_dns_timeout, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.current_open",          std::bind(&core::CurlStack::active, httpStack));
-  CMD2_ANY         ("network.http.max_open",              std::bind(&core::CurlStack::max_active, httpStack));
-  CMD2_ANY_VALUE_V ("network.http.max_open.set",          std::bind(&core::CurlStack::set_max_active, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.proxy_address",         std::bind(&core::CurlStack::http_proxy, httpStack));
-  CMD2_ANY_STRING_V("network.http.proxy_address.set",     std::bind(&core::CurlStack::set_http_proxy, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.ssl_verify_host",       std::bind(&core::CurlStack::ssl_verify_host, httpStack));
-  CMD2_ANY_VALUE_V ("network.http.ssl_verify_host.set",   std::bind(&core::CurlStack::set_ssl_verify_host, httpStack, std::placeholders::_2));
-  CMD2_ANY         ("network.http.ssl_verify_peer",       std::bind(&core::CurlStack::ssl_verify_peer, httpStack));
-  CMD2_ANY_VALUE_V ("network.http.ssl_verify_peer.set",   std::bind(&core::CurlStack::set_ssl_verify_peer, httpStack, std::placeholders::_2));
+  CMD2_ANY         ("network.http.cacert",                [http_stack](auto, auto) { return http_stack->http_cacert(); });
+  CMD2_ANY_STRING_V("network.http.cacert.set",            [http_stack](auto, auto& str) { return http_stack->set_http_cacert(str); });
+  CMD2_ANY         ("network.http.capath",                [http_stack](auto, auto) { return http_stack->http_capath(); });
+  CMD2_ANY_STRING_V("network.http.capath.set",            [http_stack](auto, auto& str) { return http_stack->set_http_capath(str); });
+  CMD2_ANY         ("network.http.dns_cache_timeout",     [http_stack](auto, auto) { return http_stack->dns_timeout(); });
+  CMD2_ANY_VALUE_V ("network.http.dns_cache_timeout.set", [http_stack](auto, auto& value) { return http_stack->set_dns_timeout(value); });
+  CMD2_ANY         ("network.http.current_open",          [http_stack](auto, auto) { return http_stack->active(); });
+  CMD2_ANY         ("network.http.max_open",              [http_stack](auto, auto) { return http_stack->max_active(); });
+  CMD2_ANY_VALUE_V ("network.http.max_open.set",          [http_stack](auto, auto& value) { return http_stack->set_max_active(value); });
+  CMD2_ANY         ("network.http.proxy_address",         [http_stack](auto, auto) { return http_stack->http_proxy(); });
+  CMD2_ANY_STRING_V("network.http.proxy_address.set",     [http_stack](auto, auto& str) { return http_stack->set_http_proxy(str); });
+  CMD2_ANY         ("network.http.ssl_verify_host",       [http_stack](auto, auto) { return http_stack->ssl_verify_host(); });
+  CMD2_ANY_VALUE_V ("network.http.ssl_verify_host.set",   [http_stack](auto, auto& value) { return http_stack->set_ssl_verify_host(value); });
+  CMD2_ANY         ("network.http.ssl_verify_peer",       [http_stack](auto, auto) { return http_stack->ssl_verify_peer(); });
+  CMD2_ANY_VALUE_V ("network.http.ssl_verify_peer.set",   [http_stack](auto, auto& value) { return http_stack->set_ssl_verify_peer(value); });
 
   CMD2_ANY         ("network.send_buffer.size",        std::bind(&torrent::ConnectionManager::send_buffer_size, cm));
   CMD2_ANY_VALUE_V ("network.send_buffer.size.set",    std::bind(&torrent::ConnectionManager::set_send_buffer_size, cm, std::placeholders::_2));
@@ -267,6 +242,8 @@ initialize_command_network() {
   CMD2_ANY_VALUE_V ("network.block.ipv4.set",        std::bind(&torrent::ConnectionManager::set_block_ipv4, cm, std::placeholders::_2));
   CMD2_ANY         ("network.block.ipv6",            std::bind(&torrent::ConnectionManager::is_block_ipv6, cm));
   CMD2_ANY_VALUE_V ("network.block.ipv6.set",        std::bind(&torrent::ConnectionManager::set_block_ipv6, cm, std::placeholders::_2));
+  CMD2_ANY         ("network.block.ipv4in6",         std::bind(&torrent::ConnectionManager::is_block_ipv4in6, cm));
+  CMD2_ANY_VALUE_V ("network.block.ipv4in6.set",     std::bind(&torrent::ConnectionManager::set_block_ipv4in6, cm, std::placeholders::_2));
 
   CMD2_ANY         ("network.prefer.ipv6",           std::bind(&torrent::ConnectionManager::is_prefer_ipv6, cm));
   CMD2_ANY_VALUE_V ("network.prefer.ipv6.set",       std::bind(&torrent::ConnectionManager::set_prefer_ipv6, cm, std::placeholders::_2));
