@@ -18,6 +18,7 @@
 #include <torrent/exceptions.h>
 #include <torrent/object_stream.h>
 #include <torrent/throttle.h>
+#include <torrent/net/http_stack.h>
 #include <torrent/utils/log.h>
 
 #include "rpc/parse_commands.h"
@@ -26,15 +27,13 @@
 #include "utils/file_status_cache.h"
 
 #include "globals.h"
-#include "curl_get.h"
-#include "curl_stack.h"
 #include "control.h"
-#include "download.h"
-#include "download_factory.h"
-#include "download_store.h"
-#include "http_queue.h"
-#include "manager.h"
-#include "view.h"
+#include "core/download.h"
+#include "core/download_factory.h"
+#include "core/download_store.h"
+#include "core/http_queue.h"
+#include "core/manager.h"
+#include "core/view.h"
 
 namespace core {
 
@@ -57,7 +56,6 @@ Manager::Manager() :
   m_download_list     = std::make_unique<DownloadList>();
   m_file_status_cache = std::make_unique<FileStatusCache>();
   m_http_queue        = std::make_unique<HttpQueue>();
-  m_http_stack        = std::make_unique<CurlStack>();
 
   torrent::Throttle* unthrottled = torrent::Throttle::create_throttle();
   unthrottled->set_max_rate(0);
@@ -131,39 +129,24 @@ Manager::retrieve_throttle_value(const torrent::Object::string_type& name, bool
   }
 }
 
-// Most of this should be possible to move out.
-void
-Manager::initialize_second() {
-  torrent::Http::slot_factory() = std::bind(&CurlStack::new_object, m_http_stack.get());
-  m_http_queue->set_slot_factory(std::bind(&CurlStack::new_object, m_http_stack.get()));
-
-  CurlStack::global_init();
-}
-
 void
 Manager::cleanup() {
-  m_http_stack->shutdown();
-
   // Need to disconnect log signals? Not really since we won't receive
   // any more.
 
   m_download_list->clear();
 
-  // When we implement asynchronous DNS lookups, we need to cancel them
-  // here before the torrent::* objects are deleted.
-
   torrent::cleanup();
-
-  m_http_stack.reset();
-  CurlStack::global_cleanup();
 }
 
 void
 Manager::shutdown(bool force) {
   if (!force)
-    std::for_each(m_download_list->begin(), m_download_list->end(), [this](Download* d) { m_download_list->pause_default(d); });
+    for (auto d : *m_download_list)
+      m_download_list->pause_default(d);
   else
-    std::for_each(m_download_list->begin(), m_download_list->end(), [this](Download* d) { m_download_list->close_quick(d); });
+    for (auto d : *m_download_list)
+      m_download_list->close_quick(d);
 }
 
 void
@@ -176,15 +159,11 @@ Manager::listen_open() {
   int portFirst, portLast;
   torrent::Object portRange = rpc::call_command("network.port_range");
 
-  if (portRange.is_string()) {
-    if (std::sscanf(portRange.as_string().c_str(), "%i-%i", &portFirst, &portLast) != 2)
-      throw torrent::input_error("Invalid port_range argument.");
+  if (!portRange.is_string())
+    throw torrent::input_error("Invalid port_range argument type.");
 
-//   } else if (portRange.is_list()) {
-
-  } else {
+  if (std::sscanf(portRange.as_string().c_str(), "%i-%i", &portFirst, &portLast) != 2)
     throw torrent::input_error("Invalid port_range argument.");
-  }
 
   if (portFirst > portLast || portLast >= (1 << 16))
     throw torrent::input_error("Invalid port range.");
@@ -229,7 +208,10 @@ Manager::set_bind_address(const std::string& addr) {
       torrent::connection_manager()->set_bind_address(ai->address()->c_sockaddr());
     }
 
-    m_http_stack->set_bind_address(!ai->address()->is_address_any() ? ai->address()->address_str() : std::string());
+    if (ai->address()->is_address_any())
+      torrent::net_thread::http_stack()->set_bind_address(std::string());
+    else
+      torrent::net_thread::http_stack()->set_bind_address(ai->address()->address_str());
 
     rak::address_info::free_address_info(ai);
 
@@ -364,8 +346,8 @@ Manager::try_create_download_from_meta_download(torrent::Object* bencode, const
 
   torrent::Object& meta = bencode->get_key("rtorrent_meta_download");
   torrent::Object::list_type& commands = meta.get_key_list("commands");
-  for (torrent::Object::list_type::const_iterator itr = commands.begin(); itr != commands.end(); ++itr)
-    f->commands().insert(f->commands().end(), itr->as_string());
+  for (const auto& command : commands)
+    f->commands().insert(f->commands().end(), command.as_string());
 
   f->set_start(meta.get_key_value("start"));
   f->set_print_log(meta.get_key_value("print_log"));
@@ -418,22 +400,22 @@ path_expand(std::vector<std::string>* paths, const std::string& pattern) {
 
     // Special case for ".."?
 
-    for (std::vector<utils::Directory>::iterator itr = currentCache.begin(); itr != currentCache.end(); ++itr) {
+    for (auto& itr : currentCache) {
       // Only include filenames starting with '.' if the pattern
       // starts with the same.
-      itr->update((r.pattern()[0] != '.') ? utils::Directory::update_hide_dot : 0);
-      itr->erase(std::remove_if(itr->begin(), itr->end(), [r](const utils::directory_entry& entry) { return !r(entry.s_name); }), itr->end());
+      itr.update((r.pattern()[0] != '.') ? utils::Directory::update_hide_dot : 0);
+      itr.erase(std::remove_if(itr.begin(), itr.end(), [r](const utils::directory_entry& entry) { return !r(entry.s_name); }), itr.end());
 
-      std::transform(itr->begin(), itr->end(), std::back_inserter(nextCache), [itr](const utils::directory_entry& entry) {
-          return path_expand_transform(itr->path() + (itr->path() == "/" ? "" : "/"), entry);
-        });
+      for (const auto& cache : itr)
+        nextCache.push_back(path_expand_transform(itr.path() + (itr.path() == "/" ? "" : "/"), cache));
     }
 
     currentCache.clear();
     currentCache.swap(nextCache);
   }
 
-  std::transform(currentCache.begin(), currentCache.end(), std::back_inserter(*paths), std::mem_fn(&utils::Directory::path));
+  for (const auto& cache : currentCache)
+    paths->push_back(cache.path());
 }
 
 bool
@@ -454,8 +436,8 @@ Manager::try_create_download_expand(const std::string& uri, int flags, command_l
   path_expand(&paths, uri);
 
   if (!paths.empty())
-    for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); ++itr)
-      try_create_download(*itr, flags, commands);
+    for (auto& path : paths)
+      try_create_download(path, flags, commands);
 
   else
     try_create_download(uri, flags, commands);
@@ -466,8 +448,8 @@ Manager::try_create_download_expand(const std::string& uri, int flags, command_l
 // hashing view and starts hashing if nessesary.
 void
 Manager::receive_hashing_changed() {
-  bool foundHashing = std::find_if(m_hashingView->begin_visible(), m_hashingView->end_visible(),
-                                   std::mem_fn(&Download::is_hash_checking)) != m_hashingView->end_visible();
+  bool foundHashing = std::any_of(m_hashingView->begin_visible(), m_hashingView->end_visible(),
+                                   std::mem_fn(&Download::is_hash_checking));
 
   // Try quick hashing all those with hashing == initial, set them to
   // something else when failed.
