@@ -16,7 +16,7 @@
 namespace core {
 
 // Also add focus thingie here?
-struct view_downloads_compare : std::function<bool (Download*, Download*)> {
+struct view_downloads_compare {
   view_downloads_compare(const torrent::Object& cmd) :
       m_command(cmd) {}
 
@@ -50,7 +50,7 @@ struct view_downloads_compare : std::function<bool (Download*, Download*)> {
   const torrent::Object& m_command;
 };
 
-struct view_downloads_filter : std::function<bool (Download*)> {
+struct view_downloads_filter {
   view_downloads_filter(const torrent::Object& cmd, const torrent::Object& cmd2) :
       m_command(cmd), m_command2(cmd2) {}
 
@@ -118,8 +118,8 @@ View::emit_changed() {
 
 void
 View::emit_changed_now() {
-  for (signal_void::iterator itr = m_signal_changed.begin(), last = m_signal_changed.end(); itr != last; itr++)
-    (*itr)();
+  for (auto& itr : m_signal_changed)
+    itr();
 }
 
 View::~View() {
@@ -138,12 +138,11 @@ View::initialize(const std::string& name) {
   if (name.empty())
     throw torrent::internal_error("View::initialize(...) called with an empty name.");
 
-  core::DownloadList* dlist = control->core()->download_list();
-
   m_name = name;
 
   // Urgh, wrong. No filtering being done.
-  std::for_each(dlist->begin(), dlist->end(), [&](Download* d) { push_back(d); });
+  for (const auto& d : *control->core()->download_list())
+    push_back(d);
 
   m_size  = base_type::size();
   m_focus = 0;
@@ -347,7 +346,7 @@ View::clear_filter_on() {
 
 inline void
 View::insert_visible(Download* d) {
-  iterator itr = std::find_if(begin_visible(), end_visible(), [&d, this](Download* d2) { return view_downloads_compare(m_sortNew)(d, d2); });
+  auto itr = std::find_if(begin_visible(), end_visible(), [this, d](auto d2) { return view_downloads_compare(m_sortNew)(d, d2); });
 
   m_size++;
   m_focus += (m_focus >= position(itr));
