@@ -7,11 +7,12 @@
 #include <sstream>
 #include <string>
 #include <inttypes.h>
+#include <typeinfo>
 #include <unistd.h>
-#include <torrent/http.h>
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
 #include <torrent/data/chunk_utils.h>
+#include <torrent/utils/chrono.h>
 #include <torrent/utils/log.h>
 #include <rak/error_number.h>
 
@@ -82,15 +83,44 @@ parse_options(int argc, char** argv) {
   }
 }
 
+void
+initialize_rpc_slots() {
+  rpc::rpc.slot_find_download() = [](const char* hash) {
+      return control->core()->download_list()->find_hex_ptr(hash);
+    };
+  rpc::rpc.slot_find_file() = [](core::Download* d, uint32_t index) -> torrent::File* {
+      if (index >= d->file_list()->size_files())
+        throw torrent::input_error("invalid parameters: index not found");
+
+      return (*d->file_list())[index].get();
+    };
+  rpc::rpc.slot_find_tracker() = [](core::Download* d, uint32_t index) -> torrent::tracker::Tracker {
+      if (index >= d->tracker_controller().size())
+        throw torrent::input_error("invalid parameters: index not found");
+
+      // TODO: This should be rewritten to check if the tracker is valid and use a different
+      // function.
+      return d->tracker_controller().at(index);
+    };
+  rpc::rpc.slot_find_peer() = [](core::Download* d, const torrent::HashString& hash) -> torrent::Peer* {
+      auto itr = d->connection_list()->find(hash.c_str());
+
+      if (itr == d->connection_list()->end())
+        throw torrent::input_error("invalid parameters: hash not found");
+
+      return *itr;
+    };
+}
+
 void
 load_session_torrents() {
   utils::Directory entries = control->core()->download_store()->get_formated_entries();
 
-  for (utils::Directory::const_iterator first = entries.begin(), last = entries.end(); first != last; ++first) {
+  for (const auto& entry : entries) {
     // We don't really support session torrents that are links. These
     // would be overwritten anyway on exit, and thus not really be
     // useful.
-    if (!first->is_file())
+    if (!entry.is_file())
       continue;
 
     core::DownloadFactory* f = new core::DownloadFactory(control->core());
@@ -99,7 +129,7 @@ load_session_torrents() {
     f->set_session(true);
     f->set_init_load(true);
     f->slot_finished([f](){ delete f; });
-    f->load(entries.path() + first->s_name);
+    f->load(entries.path() + entry.s_name);
     f->commit();
   }
 }
@@ -174,8 +204,14 @@ main(int argc, char** argv) {
     if (torrent::utils::Thread::should_handle_sigusr1())
       SignalHandler::set_handler(SIGUSR1, std::bind(&do_nothing));
 
-    torrent::log_add_group_output(torrent::LOG_NOTICE, "important");
-    torrent::log_add_group_output(torrent::LOG_INFO, "complete");
+    torrent::log_add_group_output(torrent::LOG_NOTICE,    "important");
+    torrent::log_add_group_output(torrent::LOG_DHT_ERROR, "important");
+
+    torrent::log_add_group_output(torrent::LOG_INFO,           "complete");
+    torrent::log_add_group_output(torrent::LOG_DHT_ERROR,      "complete");
+    torrent::log_add_group_output(torrent::LOG_DHT_CONTROLLER, "complete");
+
+    initialize_rpc_slots();
 
     torrent::initialize();
     torrent::set_main_thread_slots(std::bind(&client_perform));
@@ -456,8 +492,10 @@ main(int argc, char** argv) {
   } catch (torrent::internal_error& e) {
     control->cleanup_exception();
 
-    std::cout << "Caught internal_error: " << e.what() << std::endl
+    std::cout << "rtorrent: caught torrent::internal_error: "
+              << e.what() << std::endl
               << e.backtrace();
+
     lt_log_print_dump(torrent::LOG_CRITICAL, e.backtrace().c_str(), e.backtrace().size(),
                       "Caught internal_error: '%s'.", e.what());
     return -1;
@@ -465,7 +503,8 @@ main(int argc, char** argv) {
   } catch (std::exception& e) {
     control->cleanup_exception();
 
-    std::cout << "rtorrent: " << e.what() << std::endl;
+    std::cout << "rtorrent: caught" << typeid(e).name() << " : " << e.what() << std::endl;
+
     lt_log_print(torrent::LOG_CRITICAL, "Caught exception: '%s'.", e.what());
     return -1;
   }
@@ -590,7 +629,7 @@ do_panic(int signum) {
 
 void
 print_help() {
-  std::cout << "Rakshasa's BitTorrent client version " VERSION "." << std::endl;
+  std::cout << "Rakshasa's BitTorrent client version " PACKAGE_VERSION "." << std::endl;
   std::cout << std::endl;
   std::cout << "All value pairs (f.ex rate and queue size) will be in the UP/DOWN" << std::endl;
   std::cout << "order. Use the up/down/left/right arrow keys to move between screens." << std::endl;
