@@ -295,8 +295,8 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
       const std::string& str = object.as_string();
       char buffer[str.size() + 1];
       char* dst = buffer;
-      for (std::string::const_iterator itr = str.begin(); itr != str.end(); ++itr)
-        *dst++ = ((*itr < 0x20 && *itr != '\r' && *itr != '\n' && *itr != '\t') || (*itr & 0x80)) ? '?' : *itr;
+      for (char itr : str)
+        *dst++ = ((itr < 0x20 && itr != '\r' && itr != '\n' && itr != '\t') || (itr & 0x80)) ? '?' : itr;
       *dst = 0;
 
       result = xmlrpc_string_new(env, buffer);
@@ -309,8 +309,8 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
   {
     xmlrpc_value* result = xmlrpc_array_new(env);
 
-    for (torrent::Object::list_const_iterator itr = object.as_list().begin(), last = object.as_list().end(); itr != last; itr++) {
-      xmlrpc_value* item = object_to_xmlrpc(env, *itr);
+    for (const auto& itr : object.as_list()) {
+      xmlrpc_value* item = object_to_xmlrpc(env, itr);
       xmlrpc_array_append_item(env, result, item);
       xmlrpc_DECREF(item);
     }
@@ -322,9 +322,9 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
   {
     xmlrpc_value* result = xmlrpc_struct_new(env);
 
-    for (torrent::Object::map_const_iterator itr = object.as_map().begin(), last = object.as_map().end(); itr != last; itr++) {
-      xmlrpc_value* item = object_to_xmlrpc(env, itr->second);
-      xmlrpc_struct_set_value(env, result, itr->first.c_str(), item);
+    for (const auto& itr : object.as_map()) {
+      xmlrpc_value* item = object_to_xmlrpc(env, itr.second);
+      xmlrpc_struct_set_value(env, result, itr.first.c_str(), item);
       xmlrpc_DECREF(item);
     }
 
@@ -340,11 +340,8 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
     xmlrpc_DECREF(key_item);
 
     if (object.as_dict_obj().is_list()) {
-      for (torrent::Object::list_const_iterator
-             itr = object.as_dict_obj().as_list().begin(),
-             last = object.as_dict_obj().as_list().end();
-           itr != last; itr++) {
-        xmlrpc_value* item = object_to_xmlrpc(env, *itr);
+      for (const auto& itr : object.as_dict_obj().as_list()) {
+        xmlrpc_value* item = object_to_xmlrpc(env, itr);
         xmlrpc_array_append_item(env, result, item);
         xmlrpc_DECREF(item);
       }
