@@ -27,6 +27,36 @@
 
 namespace ui {
 
+static const int emacs_keymap[RT_KEYMAP_MAX] = {
+  'B' - '@',
+  'F' - '@',
+  'P' - '@',
+  'N' - '@',
+  'U' - '@',
+  'H' - '@',
+  'A' - '@',
+  'E' - '@',
+  'D' - '@', // RT_KEY_DELETE_ITEM
+  'k',       // RT_KEY_DISCONNECT_PEER
+  'l',       // RT_KEY_DISPLAY_LOG
+  'L'        // RT_KEY_TOGGLE_LAYOUT
+};
+
+static const int vi_keymap[RT_KEYMAP_MAX] = {
+  'h',
+  'l',
+  'k',
+  'j',
+  'B' - '@',
+  'D' - '@',
+  'H',
+  'G',
+  'x',       // RT_KEY_DELETE_ITEM
+  'K',       // RT_KEY_DISCONNECT_PEER
+  'L',       // RT_KEY_DISPLAY_LOG
+  'L' - '@'  // RT_KEY_TOGGLE_LAYOUT
+};
+
 Root::Root() {
   // Initialise prefilled m_input_history and m_input_history_pointers objects.
   for (int type = ui::DownloadList::INPUT_LOAD_DEFAULT; type != ui::DownloadList::INPUT_EOI; type++) {
@@ -34,6 +64,9 @@ Root::Root() {
     m_input_history_pointers.insert( std::make_pair(type, 0) );
   }
 
+  // set default keymap to emacs
+  m_keymap_style = "emacs";
+  m_keymap = emacs_keymap;
 }
 
 void
@@ -318,20 +351,19 @@ Root::set_input_history_size(int size) {
   if (size < 1)
     throw torrent::input_error("Invalid input history size.");
 
-  for (InputHistory::iterator itr = m_input_history.begin(), last = m_input_history.end(); itr != last; itr++) {
+  for (auto& [entry, category] : m_input_history) {
     // Reserve the latest input history entries if new size is smaller than original.
     if (size < m_input_history_length) {
       int pointer_offset = m_input_history_length - size;
-      InputHistoryPointers::iterator pitr = m_input_history_pointers.find(itr->first);
-      InputHistoryCategory input_history_category_tmp = itr->second;
+      InputHistoryPointers::iterator pitr           = m_input_history_pointers.find(entry);
 
       for (int i=0; i != size; i++)
-        itr->second.at(i) = input_history_category_tmp.at((pitr->second + pointer_offset + i) % m_input_history_length);
+        category.at(i) = category.at((pitr->second + pointer_offset + i) % m_input_history_length);
 
       m_input_history_pointers[pitr->first] = 0;
     }
 
-    itr->second.resize(size);
+    category.resize(size);
   }
 
   m_input_history_length = size;
@@ -381,20 +413,20 @@ Root::load_input_history() {
       lt_log_print(torrent::LOG_DEBUG, "input history file read (path:%s)", history_filename.c_str());
     }
 
-    for (InputHistory::const_iterator itr = input_history_tmp.begin(), last = input_history_tmp.end(); itr != last; itr++) {
-      int input_history_tmp_category_length = itr->second.size();
-      InputHistory::iterator hitr = m_input_history.find(itr->first);
-      InputHistoryPointers::iterator pitr = m_input_history_pointers.find(itr->first);
+    for (const auto& [entry, category] : input_history_tmp) {
+      int                            input_history_tmp_category_length = category.size();
+      InputHistory::iterator         hitr                              = m_input_history.find(entry);
+      InputHistoryPointers::iterator pitr                              = m_input_history_pointers.find(entry);
 
       if (m_input_history_length < input_history_tmp_category_length) {
         int pointer_offset = input_history_tmp_category_length - m_input_history_length;
 
         for (int i=0; i != m_input_history_length; i++)
-          hitr->second.at(i) = itr->second.at((pointer_offset + i) % input_history_tmp_category_length);
+          hitr->second.at(i) = category.at((pointer_offset + i) % input_history_tmp_category_length);
 
         pitr->second = 0;
       } else {
-        hitr->second = itr->second;
+        hitr->second = category;
         hitr->second.resize(m_input_history_length);
 
         pitr->second = input_history_tmp_category_length % m_input_history_length;
@@ -419,12 +451,12 @@ Root::save_input_history() {
     return;
   }
 
-  for (InputHistory::const_iterator itr = m_input_history.begin(), last = m_input_history.end(); itr != last; itr++) {
-    InputHistoryPointers::const_iterator pitr = m_input_history_pointers.find(itr->first);
+  for (const auto& [entry, category] : m_input_history) {
+    InputHistoryPointers::const_iterator pitr = m_input_history_pointers.find(entry);
 
     for (int i=0; i != m_input_history_length; i++)
-      if (!itr->second.at((pitr->second + i) % m_input_history_length).empty())
-        history_file << itr->first << "|" + itr->second.at((pitr->second + i) % m_input_history_length) + "\n";
+      if (!category.at((pitr->second + i) % m_input_history_length).empty())
+        history_file << entry << "|" + category.at((pitr->second + i) % m_input_history_length) + "\n";
   }
 
   if (!history_file.good()) {
@@ -451,4 +483,22 @@ Root::clear_input_history() {
   }
 }
 
+void
+Root::set_keymap_style(const std::string& style) {
+  if (style == "vi") {
+    m_keymap = vi_keymap;
+  } else if (style == "emacs") {
+    m_keymap = emacs_keymap;
+  } else {
+    throw torrent::input_error("Root::set_keymap_style() -> ui.keymap.style is configured with unknown keymap style: " + m_keymap_style);
+  }
+
+  m_keymap_style = style;
+}
+
+const int
+Root::navigation_key(NavigationKeymap key) {
+  return m_keymap[key];
+}
+
 }
